#!/bin/bash

set -e

cd "$( dirname "${BASH_SOURCE[0]}" )"

if [ -z "$REVISE_ROOT_DIR" ]
then
    echo Please specify path to ReVisE root directory in the REVISE_ROOT_DIR environment variable
    exit 1
fi

source "$REVISE_ROOT_DIR/scripts/env.sh"

source ./description.sh "$@"

if [ -f "${REVISE_DATASET_NAME}#revise_ready" ]
then
    echo "Dataset $REVISE_DATASET_NAME is up to date"
    exit 0
fi

mkdir -p "$REVISE_DATASET_NAME"

# GENERATE
tecplot_gen --type sphere --dim 3 \
    --N "$REVISE_DATASET_PARAM_N" \
    --tn "$REVISE_DATASET_PARAM_TIME_STEPS" \
    --output "$REVISE_DATASET_NAME/sphere.bin"

# PREPROCESS
s3dmm_prep --dim 3 \
    --depth "$REVISE_DATASET_PARAM_DEPTH" \
    --brefine "$REVISE_DATASET_PARAM_BREFINE" \
    --mesh_file "$REVISE_DATASET_NAME/sphere.bin" \
    --max_full_level "$REVISE_DATASET_PARAM_MAX_LEVEL" \
    --max_level "$REVISE_DATASET_PARAM_MAX_LEVEL" \
    -t 10

# Collect metadata information for the ReVisE dataset
s3dmm_prep --mode meta_info "$REVISE_DATASET_NAME/sphere.bin" 2>&1 |tee "$REVISE_DATASET_NAME/metadata_info.tsv"

echo >"${REVISE_DATASET_NAME}#revise_ready"
